@@ -1,13 +1,17 @@
 ; -*- Lisp -*-
 (in-package :maxima)
 
+(defparameter *autoconf-variables-set* "@variables_set@")
 (defparameter *autoconf-prefix* "/usr/local")
 (defparameter *autoconf-exec_prefix* "/usr/local")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.9.0")
+(defparameter *autoconf-version* "5.13.0")
 (defparameter *autoconf-libdir* "/usr/local/lib")
 (defparameter *autoconf-libexecdir* "/usr/local/libexec")
 (defparameter *autoconf-datadir* "/usr/local/share")
 (defparameter *autoconf-infodir* "/usr/local/info")
-(defparameter *autoconf-host* "i386-unknown-openbsd4.0")
+(defparameter *autoconf-host* "i386-unknown-openbsd4.4")
+(defparameter *autoconf-win32* "false")
  
+(defparameter *maxima-source-root* "/usr/obj/i386/maxima-5.13.0/maxima-5.13.0")
+(defparameter *maxima-default-layout-autotools* "true")
